@@ -1,6 +1,9 @@
 
 from hyperopt import fmin, tpe, hp, STATUS_OK, Trials
-from fml.validates import validate_switch
+if __name__ == "__main__":
+    from fml.validates import validate_switch
+else:
+    from ..validates import validate_switch
 import numpy as np
 
 def single_hyperopt(X, Y, algo, flen, loo=10):
@@ -12,6 +15,7 @@ def single_hyperopt(X, Y, algo, flen, loo=10):
     trials = Trials()
     
     def f(params):
+        print(params)
         result = validate_switch(loo, algo, X[:, np.array(list(params.values()))], Y)
         if len(set(Y)) > 8:
             loss = result["rmse"]
